==> qtjambi-virtualkeyboard-jre8-6.2-sources.jar: io/qt/keyboard/QtJambi_LibraryUtilities.java <==
package io.qt.keyboard;

final class QtJambi_LibraryUtilities {
    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("Qml");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("opengl32sw"))
                io.qt.QtUtilities.loadUtilityLibrary("opengl32sw");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("d3dcompiler_47"))
                io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47");
            io.qt.QtUtilities.loadQtLibrary("OpenGL");
            io.qt.QtUtilities.loadQtLibrary("DBus");
            io.qt.QtUtilities.loadQtLibrary("QmlModels");
            io.qt.QtUtilities.loadQtLibrary("Quick");
            io.qt.QtUtilities.loadQtLibrary("VirtualKeyboard");
            io.qt.QtUtilities.loadQtJambiLibrary("VirtualKeyboard");
        } catch(RuntimeException | Error t) {
            throw t;
        } catch(Throwable t) {
            throw new RuntimeException(t);
        }
    }

    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-virtualkeyboard-jre8-6.2.3-sources.jar: io/qt/keyboard/QtJambi_LibraryUtilities.java <==
package io.qt.keyboard;

final class QtJambi_LibraryUtilities {
    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("Qml");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("opengl32sw"))
                io.qt.QtUtilities.loadUtilityLibrary("opengl32sw");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("d3dcompiler_47"))
                io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47");
            io.qt.QtUtilities.loadQtLibrary("OpenGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("DBus"))
                io.qt.QtUtilities.loadQtLibrary("DBus");
            io.qt.QtUtilities.loadQtLibrary("QmlModels");
            io.qt.QtUtilities.loadQtLibrary("Quick");
            io.qt.QtUtilities.loadQtLibrary("VirtualKeyboard");
            io.qt.QtUtilities.loadQtJambiLibrary("VirtualKeyboard");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }

    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
